# Generated by roxygen2: do not edit by hand

export(accepted_names)
export(any_match_count)
export(comment_detail)
export(common_names)
export(core_metadata)
export(coverage)
export(credibility_rating)
export(credibility_ratings)
export(currency)
export(date_data)
export(description)
export(experts)
export(full_record)
export(geographic_divisions)
export(geographic_values)
export(global_species_completeness)
export(hierarchy_down)
export(hierarchy_full)
export(hierarchy_up)
export(itis_facet)
export(itis_group)
export(itis_highlight)
export(itis_search)
export(jurisdiction_origin_values)
export(jurisdiction_values)
export(jurisdictional_origin)
export(kingdom_name)
export(kingdom_names)
export(last_change_date)
export(lsid2tsn)
export(other_sources)
export(parent_tsn)
export(publications)
export(rank_name)
export(rank_names)
export(record)
export(review_year)
export(scientific_name)
export(search_any_match_paged)
export(search_anymatch)
export(search_common)
export(search_scientific)
export(synonym_names)
export(taxon_authorship)
export(terms)
export(tsn2lsid)
export(tsn_by_vernacular_language)
export(unacceptability_reason)
export(usage)
export(vernacular_languages)
