## ---- echo = FALSE, warning = FALSE, message = FALSE---------------------
NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "true")
knitr::opts_chunk$set(
  collapse  =  TRUE,
  comment  =  "#>",
  warning = FALSE,
  message = FALSE,
  purl  =  NOT_CRAN,
  eval  =  NOT_CRAN
)

