#' ITIS Solr Methods
#'
#' ITIS provides access to their data via their Solr service described at
#' <https://www.itis.gov/solr_documentation.html>.  This is a powerful
#' interace to ITIS data as you have access to a very flexible query
#' interface.
#' 
#' See [solr_fields] and <https://www.itis.gov/solr_documentation.html> 
#' for guidance on available fields.
#'
#' @section Functions:
#'
#'  - [itis_search()] - Search
#'  - [itis_group()] - Group
#'  - [itis_highlight()] - Highlight
#'  - [itis_facet()] - Facet
#'
#' @name solr
NULL
